@@ -34,15 +34,21 @@ void Cli7zTest::initTestCase()
 void Cli7zTest::testArchive_data()
 {
     QTest::addColumn<QString>("archivePath");
-    QTest::addColumn<QString>("expectedFileName");
+    QTest::addColumn<QString>("expectedBaseName");
     QTest::addColumn<bool>("isReadOnly");
     QTest::addColumn<bool>("isSingleFolder");
+    QTest::addColumn<bool>("isMultiVolume");
+    QTest::addColumn<int>("numberOfVolumes");
     QTest::addColumn<Archive::EncryptionType>("expectedEncryptionType");
     QTest::addColumn<QString>("expectedSubfolderName");
 
     QString archivePath = QFINDTESTDATA("data/one_toplevel_folder.7z");
     QTest::newRow("archive with one top-level folder")
-        << archivePath << QFileInfo(archivePath).fileName() << false << true << Archive::Unencrypted << QStringLiteral("A");
+        << archivePath << QStringLiteral("one_toplevel_folder") << false << true << false << 0 << Archive::Unencrypted << QStringLiteral("A");
+
+    archivePath = QFINDTESTDATA("data/archive-multivolume.7z.001");
+    QTest::newRow("7z multivolume") << archivePath << QStringLiteral("archive-multivolume") << true << false << true << 3 << Archive::Unencrypted
+                                    << QStringLiteral("archive-multivolume");
 }
 
 void Cli7zTest::testArchive()
@@ -63,8 +69,8 @@ void Cli7zTest::testArchive()
         QSKIP("Could not load the cli7z plugin. Skipping test.", SkipSingle);
     }
 
-    QFETCH(QString, expectedFileName);
-    QCOMPARE(QFileInfo(archive->fileName()).fileName(), expectedFileName);
+    QFETCH(QString, expectedBaseName);
+    QCOMPARE(archive->completeBaseName(), expectedBaseName);
 
     QFETCH(bool, isReadOnly);
     QCOMPARE(archive->isReadOnly(), isReadOnly);
@@ -72,6 +78,12 @@ void Cli7zTest::testArchive()
     QFETCH(bool, isSingleFolder);
     QCOMPARE(archive->isSingleFolder(), isSingleFolder);
 
+    QFETCH(bool, isMultiVolume);
+    QCOMPARE(archive->isMultiVolume(), isMultiVolume);
+
+    QFETCH(int, numberOfVolumes);
+    QCOMPARE(archive->numberOfVolumes(), numberOfVolumes);
+
     QFETCH(Archive::EncryptionType, expectedEncryptionType);
     QCOMPARE(archive->encryptionType(), expectedEncryptionType);
 
@@ -336,13 +348,13 @@ void Cli7zTest::testAddArgs()
 void Cli7zTest::testExtractArgs_data()
 {
     QTest::addColumn<QString>("archiveName");
-    QTest::addColumn<QVector<Archive::Entry *>>("files");
+    QTest::addColumn<QList<Archive::Entry *>>("files");
     QTest::addColumn<bool>("preservePaths");
     QTest::addColumn<QString>("password");
     QTest::addColumn<QStringList>("expectedArgs");
 
     QTest::newRow("preserve paths, encrypted") << QStringLiteral("/tmp/foo.7z")
-                                               << (QVector<Archive::Entry *>{
+                                               << (QList<Archive::Entry *>{
                                                       new Archive::Entry(this, QStringLiteral("aDir/textfile2.txt"), QStringLiteral("aDir")),
                                                       new Archive::Entry(this, QStringLiteral("c.txt"), QString()),
                                                   })
@@ -356,7 +368,7 @@ void Cli7zTest::testExtractArgs_data()
                                                   };
 
     QTest::newRow("preserve paths, unencrypted") << QStringLiteral("/tmp/foo.7z")
-                                                 << (QVector<Archive::Entry *>{
+                                                 << (QList<Archive::Entry *>{
                                                         new Archive::Entry(this, QStringLiteral("aDir/textfile2.txt"), QStringLiteral("aDir")),
                                                         new Archive::Entry(this, QStringLiteral("c.txt"), QString()),
                                                     })
@@ -369,7 +381,7 @@ void Cli7zTest::testExtractArgs_data()
                                                     };
 
     QTest::newRow("without paths, encrypted") << QStringLiteral("/tmp/foo.7z")
-                                              << (QVector<Archive::Entry *>{
+                                              << (QList<Archive::Entry *>{
                                                      new Archive::Entry(this, QStringLiteral("aDir/textfile2.txt"), QStringLiteral("aDir")),
                                                      new Archive::Entry(this, QStringLiteral("c.txt"), QString()),
                                                  })
@@ -383,7 +395,7 @@ void Cli7zTest::testExtractArgs_data()
                                                  };
 
     QTest::newRow("without paths, unencrypted") << QStringLiteral("/tmp/foo.7z")
-                                                << (QVector<Archive::Entry *>{
+                                                << (QList<Archive::Entry *>{
                                                        new Archive::Entry(this, QStringLiteral("aDir/textfile2.txt"), QStringLiteral("aDir")),
                                                        new Archive::Entry(this, QStringLiteral("c.txt"), QString()),
                                                    })
@@ -406,7 +418,7 @@ void Cli7zTest::testExtractArgs()
     CliPlugin *plugin = new CliPlugin(this, {QVariant(archiveName), QVariant::fromValue(m_plugin->metaData())});
     QVERIFY(plugin);
 
-    QFETCH(QVector<Archive::Entry *>, files);
+    QFETCH(QList<Archive::Entry *>, files);
     QStringList filesList;
     for (const Archive::Entry *e : std::as_const(files)) {
         filesList << e->fullPath(NoTrailingSlash);
